@@ -92,7 +92,7 @@ phraseList = []
 port = ""
 
 # define library version
-version = "1.267"
+version = "1.268"
 
 # flag to stop writing when writing for threading
 writing = False
@@ -523,8 +523,8 @@ def checkPort(p):
     try:
         ser = serial.Serial(p[0], 19200)
 
-        ser.timeout = 0.1
-        ser.write_timeout = 0.1
+        ser.timeout = 0.3
+        ser.write_timeout = None
         ser.flushInput()
 
         msg = "v" + "\n"
